==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/kn.py <==
info = {
    "name": "kn",
    "date_order": "DMY",
    "january": [
        "ಜನವರಿ",
        "ಜನ"
    ],
    "february": [
        "ಫೆಬ್ರವರಿ",
        "ಫೆಬ್ರ"
    ],
    "march": [
        "ಮಾರ್ಚ್"
    ],
    "april": [
        "ಏಪ್ರಿಲ್",
        "ಏಪ್ರಿ"
    ],
    "may": [
        "ಮೇ"
    ],
    "june": [
        "ಜೂನ್"
    ],
    "july": [
        "ಜುಲೈ"
    ],
    "august": [
        "ಆಗಸ್ಟ್",
        "ಆಗ"
    ],
    "september": [
        "ಸೆಪ್ಟೆಂಬರ್",
        "ಸೆಪ್ಟೆಂ"
    ],
    "october": [
        "ಅಕ್ಟೋಬರ್",
        "ಅಕ್ಟೋ"
    ],
    "november": [
        "ನವೆಂಬರ್",
        "ನವೆಂ"
    ],
    "december": [
        "ಡಿಸೆಂಬರ್",
        "ಡಿಸೆಂ"
    ],
    "monday": [
        "ಸೋಮವಾರ",
        "ಸೋಮ"
    ],
    "tuesday": [
        "ಮಂಗಳವಾರ",
        "ಮಂಗಳ"
    ],
    "wednesday": [
        "ಬುಧವಾರ",
        "ಬುಧ"
    ],
    "thursday": [
        "ಗುರುವಾರ",
        "ಗುರು"
    ],
    "friday": [
        "ಶುಕ್ರವಾರ",
        "ಶುಕ್ರ"
    ],
    "saturday": [
        "ಶನಿವಾರ",
        "ಶನಿ"
    ],
    "sunday": [
        "ಭಾನುವಾರ",
        "ಭಾನು"
    ],
    "am": [
        "ಪೂರ್ವಾಹ್ನ"
    ],
    "pm": [
        "ಅಪರಾಹ್ನ"
    ],
    "year": [
        "ವರ್ಷ"
    ],
    "month": [
        "ತಿಂಗಳು"
    ],
    "week": [
        "ವಾರ"
    ],
    "day": [
        "ದಿನ"
    ],
    "hour": [
        "ಗಂಟೆ"
    ],
    "minute": [
        "ನಿಮಿಷ"
    ],
    "second": [
        "ಸೆಕೆಂಡ್"
    ],
    "relative-type": {
        "1 year ago": [
            "ಹಿಂದಿನ ವರ್ಷ",
            "ಕಳೆದ ವರ್ಷ"
        ],
        "0 year ago": [
            "ಈ ವರ್ಷ"
        ],
        "in 1 year": [
            "ಮುಂದಿನ ವರ್ಷ"
        ],
        "1 month ago": [
            "ಕಳೆದ ತಿಂಗಳು"
        ],
        "0 month ago": [
            "ಈ ತಿಂಗಳು"
        ],
        "in 1 month": [
            "ಮುಂದಿನ ತಿಂಗಳು"
        ],
        "1 week ago": [
            "ಕಳೆದ ವಾರ"
        ],
        "0 week ago": [
            "ಈ ವಾರ"
        ],
        "in 1 week": [
            "ಮುಂದಿನ ವಾರ"
        ],
        "1 day ago": [
            "ನಿನ್ನೆ"
        ],
        "0 day ago": [
            "ಇಂದು"
        ],
        "in 1 day": [
            "ನಾಳೆ"
        ],
        "0 hour ago": [
            "ಈ ಗಂಟೆ"
        ],
        "0 minute ago": [
            "ಈ ನಿಮಿಷ"
        ],
        "0 second ago": [
            "ಈಗ"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) ವರ್ಷದಲ್ಲಿ",
            "(\\d+) ವರ್ಷಗಳಲ್ಲಿ"
        ],
        "\\1 year ago": [
            "(\\d+) ವರ್ಷದ ಹಿಂದೆ",
            "(\\d+) ವರ್ಷಗಳ ಹಿಂದೆ"
        ],
        "in \\1 month": [
            "(\\d+) ತಿಂಗಳಲ್ಲಿ",
            "(\\d+) ತಿಂಗಳುಗಳಲ್ಲಿ"
        ],
        "\\1 month ago": [
            "(\\d+) ತಿಂಗಳುಗಳ ಹಿಂದೆ",
            "(\\d+) ತಿಂಗಳು ಹಿಂದೆ",
            "(\\d+) ತಿಂಗಳ ಹಿಂದೆ"
        ],
        "in \\1 week": [
            "(\\d+) ವಾರದಲ್ಲಿ",
            "(\\d+) ವಾರಗಳಲ್ಲಿ"
        ],
        "\\1 week ago": [
            "(\\d+) ವಾರದ ಹಿಂದೆ",
            "(\\d+) ವಾರಗಳ ಹಿಂದೆ"
        ],
        "in \\1 day": [
            "(\\d+) ದಿನದಲ್ಲಿ",
            "(\\d+) ದಿನಗಳಲ್ಲಿ"
        ],
        "\\1 day ago": [
            "(\\d+) ದಿನದ ಹಿಂದೆ",
            "(\\d+) ದಿನಗಳ ಹಿಂದೆ"
        ],
        "in \\1 hour": [
            "(\\d+) ಗಂಟೆಯಲ್ಲಿ",
            "(\\d+) ಗಂಟೆಗಳಲ್ಲಿ"
        ],
        "\\1 hour ago": [
            "(\\d+) ಗಂಟೆ ಹಿಂದೆ",
            "(\\d+) ಗಂಟೆಗಳ ಹಿಂದೆ"
        ],
        "in \\1 minute": [
            "(\\d+) ನಿಮಿಷದಲ್ಲಿ",
            "(\\d+) ನಿಮಿಷಗಳಲ್ಲಿ"
        ],
        "\\1 minute ago": [
            "(\\d+) ನಿಮಿಷಗಳ ಹಿಂದೆ",
            "(\\d+) ನಿಮಿಷದ ಹಿಂದೆ"
        ],
        "in \\1 second": [
            "(\\d+) ಸೆಕೆಂಡ್‌ನಲ್ಲಿ",
            "(\\d+) ಸೆಕೆಂಡ್‌ಗಳಲ್ಲಿ"
        ],
        "\\1 second ago": [
            "(\\d+) ಸೆಕೆಂಡ್ ಹಿಂದೆ",
            "(\\d+) ಸೆಕೆಂಡುಗಳ ಹಿಂದೆ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser_1.1.0.orig.tar.gz: dateparser-1.1.0/dateparser/data/date_translation_data/kn.py <==
info = {
    "name": "kn",
    "date_order": "DMY",
    "january": [
        "ಜನ",
        "ಜನವರಿ"
    ],
    "february": [
        "ಫೆಬ್ರ",
        "ಫೆಬ್ರವರಿ"
    ],
    "march": [
        "ಮಾರ್ಚ್"
    ],
    "april": [
        "ಏಪ್ರಿ",
        "ಏಪ್ರಿಲ್"
    ],
    "may": [
        "ಮೇ"
    ],
    "june": [
        "ಜೂನ್"
    ],
    "july": [
        "ಜುಲೈ"
    ],
    "august": [
        "ಆಗ",
        "ಆಗಸ್ಟ್"
    ],
    "september": [
        "ಸೆಪ್ಟೆಂ",
        "ಸೆಪ್ಟೆಂಬರ್"
    ],
    "october": [
        "ಅಕ್ಟೋ",
        "ಅಕ್ಟೋಬರ್"
    ],
    "november": [
        "ನವೆಂ",
        "ನವೆಂಬರ್"
    ],
    "december": [
        "ಡಿಸೆಂ",
        "ಡಿಸೆಂಬರ್"
    ],
    "monday": [
        "ಸೋಮ",
        "ಸೋಮವಾರ"
    ],
    "tuesday": [
        "ಮಂಗಳ",
        "ಮಂಗಳವಾರ"
    ],
    "wednesday": [
        "ಬುಧ",
        "ಬುಧವಾರ"
    ],
    "thursday": [
        "ಗುರು",
        "ಗುರುವಾರ"
    ],
    "friday": [
        "ಶುಕ್ರ",
        "ಶುಕ್ರವಾರ"
    ],
    "saturday": [
        "ಶನಿ",
        "ಶನಿವಾರ"
    ],
    "sunday": [
        "ಭಾನು",
        "ಭಾನುವಾರ"
    ],
    "am": [
        "ಪೂರ್ವಾಹ್ನ"
    ],
    "pm": [
        "ಅಪರಾಹ್ನ"
    ],
    "year": [
        "ವರ್ಷ"
    ],
    "month": [
        "ತಿಂಗಳು"
    ],
    "week": [
        "ವಾರ"
    ],
    "day": [
        "ದಿನ"
    ],
    "hour": [
        "ಗಂಟೆ"
    ],
    "minute": [
        "ನಿಮಿಷ"
    ],
    "second": [
        "ಸೆಕೆಂಡ್"
    ],
    "relative-type": {
        "0 day ago": [
            "ಇಂದು"
        ],
        "0 hour ago": [
            "ಈ ಗಂಟೆ"
        ],
        "0 minute ago": [
            "ಈ ನಿಮಿಷ"
        ],
        "0 month ago": [
            "ಈ ತಿಂಗಳು"
        ],
        "0 second ago": [
            "ಈಗ"
        ],
        "0 week ago": [
            "ಈ ವಾರ"
        ],
        "0 year ago": [
            "ಈ ವರ್ಷ"
        ],
        "1 day ago": [
            "ನಿನ್ನೆ"
        ],
        "1 month ago": [
            "ಕಳೆದ ತಿಂಗಳು"
        ],
        "1 week ago": [
            "ಕಳೆದ ವಾರ"
        ],
        "1 year ago": [
            "ಕಳೆದ ವರ್ಷ",
            "ಹಿಂದಿನ ವರ್ಷ"
        ],
        "in 1 day": [
            "ನಾಳೆ"
        ],
        "in 1 month": [
            "ಮುಂದಿನ ತಿಂಗಳು"
        ],
        "in 1 week": [
            "ಮುಂದಿನ ವಾರ"
        ],
        "in 1 year": [
            "ಮುಂದಿನ ವರ್ಷ"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) ದಿನಗಳ ಹಿಂದೆ",
            "(\\d+) ದಿನದ ಹಿಂದೆ"
        ],
        "\\1 hour ago": [
            "(\\d+) ಗಂಟೆ ಹಿಂದೆ",
            "(\\d+) ಗಂಟೆಗಳ ಹಿಂದೆ"
        ],
        "\\1 minute ago": [
            "(\\d+) ನಿಮಿಷಗಳ ಹಿಂದೆ",
            "(\\d+) ನಿಮಿಷದ ಹಿಂದೆ"
        ],
        "\\1 month ago": [
            "(\\d+) ತಿಂಗಳ ಹಿಂದೆ",
            "(\\d+) ತಿಂಗಳು ಹಿಂದೆ",
            "(\\d+) ತಿಂಗಳುಗಳ ಹಿಂದೆ"
        ],
        "\\1 second ago": [
            "(\\d+) ಸೆಕೆಂಡುಗಳ ಹಿಂದೆ",
            "(\\d+) ಸೆಕೆಂಡ್ ಹಿಂದೆ"
        ],
        "\\1 week ago": [
            "(\\d+) ವಾರಗಳ ಹಿಂದೆ",
            "(\\d+) ವಾರದ ಹಿಂದೆ"
        ],
        "\\1 year ago": [
            "(\\d+) ವರ್ಷಗಳ ಹಿಂದೆ",
            "(\\d+) ವರ್ಷದ ಹಿಂದೆ"
        ],
        "in \\1 day": [
            "(\\d+) ದಿನಗಳಲ್ಲಿ",
            "(\\d+) ದಿನದಲ್ಲಿ"
        ],
        "in \\1 hour": [
            "(\\d+) ಗಂಟೆಗಳಲ್ಲಿ",
            "(\\d+) ಗಂಟೆಯಲ್ಲಿ"
        ],
        "in \\1 minute": [
            "(\\d+) ನಿಮಿಷಗಳಲ್ಲಿ",
            "(\\d+) ನಿಮಿಷದಲ್ಲಿ"
        ],
        "in \\1 month": [
            "(\\d+) ತಿಂಗಳಲ್ಲಿ",
            "(\\d+) ತಿಂಗಳುಗಳಲ್ಲಿ"
        ],
        "in \\1 second": [
            "(\\d+) ಸೆಕೆಂಡ್‌ಗಳಲ್ಲಿ",
            "(\\d+) ಸೆಕೆಂಡ್‌ನಲ್ಲಿ"
        ],
        "in \\1 week": [
            "(\\d+) ವಾರಗಳಲ್ಲಿ",
            "(\\d+) ವಾರದಲ್ಲಿ"
        ],
        "in \\1 year": [
            "(\\d+) ವರ್ಷಗಳಲ್ಲಿ",
            "(\\d+) ವರ್ಷದಲ್ಲಿ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
